pub struct ResourcesCapability {
pub list_changed: bool,
pub subscribe: bool,
}Expand description
Resources capability.
Fields
list_changed: boolIndicates whether the server will emit notifications when the list of available prompts changes.
subscribe: boolWhether the client can subscribe to be notified of changes to individual resources.