pub struct StructuredContent<T>(pub T);Expand description
A Structured content.
Tuple Fields
0: TTrait Implementations
Sourceimpl<T: Clone> Clone for StructuredContent<T>
impl<T: Clone> Clone for StructuredContent<T>
Sourcefn clone(&self) -> StructuredContent<T>
fn clone(&self) -> StructuredContent<T>
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<T: Debug> Debug for StructuredContent<T>
impl<T: Debug> Debug for StructuredContent<T>
Sourceimpl<T> IntoToolResponse for StructuredContent<T>where
T: Serialize + JsonSchema,
impl<T> IntoToolResponse for StructuredContent<T>where
T: Serialize + JsonSchema,
Sourcefn output_schema() -> Option<Schema>
fn output_schema() -> Option<Schema>
Returns the output schema of the tool response, if any.
Sourcefn into_tool_response(self) -> ToolsCallResponse
fn into_tool_response(self) -> ToolsCallResponse
Consumes the object and converts it into a tool response.
impl<T: Copy> Copy for StructuredContent<T>